%% MySimple.CLS
%% Written by Karnes. 2004/03/10
%% v0.1
%%
%% This Class needs as follows:
%%   book.cls
%%   hangul-nojosa, geometry, hyperref, crop, pxfonts, lineno,
%%   comment, hlatex-interword, graphicx, color, picins, eso-pic,
%%	 ifthen, hfncychap, footmisc.
%%
%% supplementary files:
%%	 everyshibackground.eps, everyshibackgroundr.eps, dessin.eps

\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{mysimple}
              [2004/03/08 v0.01 my Simple LaTeX class]

%% include book class.
\@input{book.cls}

%% include hangul=nojosa and hlatex-interword
\RequirePackage{hangul-nojosa}
\RequirePackage[default]{hlatex-interword}

%% Options
\DeclareOption{openany}{\@openrightfalse}
\newif\if@pdfmake
\DeclareOption{pdf}{\@pdfmaketrue}
\DeclareOption{a4crop}{\@pdfmakefalse}
\newif\if@linenumber
\DeclareOption{lineno}{\@linenumbertrue}
\newif\if@uhc
\DeclareOption{uhc}{\@uhctrue}
\DeclareOption{ttf}{\@uhcfalse}
\ExecuteOptions{a4crop,ttf}
\ProcessOptions

%% ѱƮ
\if@uhc
	\RequirePackage{uhc,pxfonts}
\else
	\RequirePackage{mhttf,pxfonts}
\fi

%% PageSize(ű)
\RequirePackage{geometry}
\geometry{
paperwidth=152truemm,
paperheight=224truemm,
left=23mm,
textwidth=100mm,
marginparsep=0mm,
marginparwidth=0mm,
%right=25mm,
top=27.5mm,
bottom=30mm,
headsep=8mm,
}

%% PDF or A4crop.
\if@pdfmake
	\RequirePackage[dvipdfm,urlcolor=blue,filecolor=magenta,CJKbookmarks]{hyperref}
	\AtBeginDvi{\special{pdf: pagesize width 152mm height 224mm}}
	\AtBeginDvi{\special{pdf:tounicode KSCms-UHC-UCS2}}%
	\AfterBeginDocument{%
  		\ifx\special@paper\@empty\else
%    	\ifHy@setpagesize
      	\special{papersize=\special@paper}%
%    	\fi
    	\Hy@DisableOption{setpagesize}%
  	\fi
	}
\else
	\RequirePackage[a4,cross,center]{crop}
	\RequirePackage[dvipdfm,bookmarks=false]{hyperref}
\fi

%% Linenumbering
\if@linenumber
	\RequirePackage{lineno}
\else\fi
\RequirePackage{comment}

%% include graphicx, color
\RequirePackage{graphicx,color}
\RequirePackage{xcolor}

%% include picins.
\RequirePackage{picins}

%% PageStyle using fancyhdr.
\RequirePackage{fancyhdr}
\newcommand\thisbooksname[1]{%
	\def\this@bookname{#1}}
\thisbooksname{ī ϷŰ }
\pagestyle{fancyplain}
\renewcommand{\chaptermark}[1]{%
	\markboth{\this@bookname}{\ksPrev\thechapter\ksPost\ #1}}
%\renewcommand{\sectionmark}[1]{\markright{\ksPrev\thechapter\ksPost\ #1}}
\renewcommand{\sectionmark}[1]{}
\fancyhead{} \fancyfoot{}
\fancyhead[RO]{%
	\fancyplain{\small\rightmark~~\thepage}{\small\rightmark~~\thepage}%
	}
\fancyhead[LE]{
	\fancyplain{\small\thepage~~\leftmark}{\small\thepage~~\leftmark}%
	}
\renewcommand{\headrulewidth}{0pt}

%% Document Font sizes(10.5pt)
\def\@vpt{5}
\def\@vipt{6}
\def\@viipt{7}
\def\@viiipt{8}
\def\@ninesize{9}
\def\@ixpt{9.5}
\def\@xpt{10.5}
\def\@elevensize{11.0}
\def\@xipt{11.25}
\def\@xiipt{12.24}
\def\@xivpt{15}
\def\@xviipt{17.28}
\def\@xxpt{20.74}
\def\@xxvpt{24.88}

%% from Lee Juho.
\newcommand{\cedp}{%
	\if@openright
	\newpage{%
		\pagestyle{empty}
		\ClearShipoutPicture
		\cleardoublepage}%
	\else
	\newpage{%
		\pagestyle{empty}
		\ClearShipoutPicture
		\clearpage}%
	\fi
}

%% Background
\RequirePackage{eso-pic}
\newcommand\BackgroundPicture{%
   \parbox[b][\paperheight]{\paperwidth}{%
     \vfill
     \centering
     \includegraphics[width=152.5mm,%
                     keepaspectratio]{everyshibackground}%
     \vfill
}}
\newcommand\BackgroundPictureR{%
   \parbox[b][\paperheight]{\paperwidth}{%
     \vfill
     \centering
     \includegraphics[width=152.5mm,%height=\paperheight,%
                     keepaspectratio]{everyshibackgroundr}%
     \vfill
}}

\RequirePackage{ifthen}

\newcommand\RenewMyShipoutPicture{%
	\AddToShipoutPicture{%
   	\setlength\unitlength{1mm}%
   	\ifthenelse{\isodd{\value{page}}}
   	{\put(0,3){\BackgroundPicture}}
   	{\put(0,3){\BackgroundPictureR}}
	}%
}

\RenewMyShipoutPicture

\linespread{1.33}

\setlength\parindent{1em}

%%%
%%% Part
%%%
\renewcommand \thepart {\@arabic\c@part}

\newcommand\mprt@grp{}%
\newcommand\mprtgrp[1]{%
	\@bsphack
	\renewcommand\mprt@grp{#1}%
	\@esphack
}

\newcommand\msmppart[2]{%
	\mprtgrp{#2}%
	\part{#1}%
	\thispagestyle{empty}%
	\cedp
}

\def\@part[#1]#2{%
	\AddToShipoutPicture*{%
		\setlength\unitlength{1mm}%
		\put(0,125){%
			\parbox[b]{\paperwidth}{%
				\vfill
				\centering
				\includegraphics[width=\paperwidth,%
					height=100mm]{\mprt@grp}
				\vfill
			}}%
		}			
    \ifnum \c@secnumdepth >\m@ne
      \refstepcounter{part}%
      \addcontentsline{toc}{part}{\thepart\hspace{1em}#1}%
    \else
      \addcontentsline{toc}{part}{#1}%
    \fi
    {\parindent \z@ \raggedright
     \interlinepenalty \@M
     \normalfont
     \vskip .4\textheight
     \flushright
     \ifnum \c@secnumdepth >\m@ne
       \Huge\hfontfamily{sh}\bfseries %\partname\nobreakspace\thepart
       \flushright
%       \rotatebox{-33}{%
       	\resizebox{17pt}{35pt}{%
       		\textcolor{red}{\thepart}
       	}%
%       }%
       \par\nobreak
     \fi
     \vskip 20\p@
     \minipage{.75\textwidth}
     \flushright\hfontfamily{sh}\huge \bfseries 
     \textcolor{blue}{#2}\endminipage%
     \markboth{}{}\par}%
    \nobreak
    \vskip 3ex
    \@afterheading}
\def\@spart#1{%
    {\parindent \z@ \raggedright
     \interlinepenalty \@M
     \normalfont
     \hfontfamily{sh}\huge \bfseries #1\par}%
     \nobreak
     \vskip 3ex
     \@afterheading}

%%%
%%% Chapter with hfncychap
%%%
\RequirePackage{hfncychap}
\newcommand\msmpchapter[1]{%
	\ClearShipoutPicture
	\RenewMyShipoutPicture
	\chapter{#1}\thispagestyle{fancy}
}

\renewcommand\ksPrev{}
\renewcommand\ksPost{}
  \ChNameUpperCase
  \ChTitleUpperCase  
  \ChNameVar{\centering\LARGE\rm}
  \ChNumVar{\Huge}
  \ChTitleVar{\centering\LARGE\rm\bfseries}
%  \ChRuleWidth{2pt}
  \ChRuleWidth{0pt}

  \renewcommand{\DOCH}{%
%    \mghrulefill{3\RW}\par\nobreak
%    \vskip -0.5\baselineskip
%    \mghrulefill{\RW}\par\nobreak
%    \CNV\FmN{\ksPrev}\space {\CNoV\thechapter}\space {\CNV\FmN{\ksPost}}
    \CNV\FmN\CNoV\thechapter%
    \RenewMyShipoutPicture
    \par
    \vskip -.3\baselineskip
    \centerline{$\cdot$}%
    \vskip -.2\baselineskip
    \par\nobreak
%    \vskip -0.5\baselineskip
   }

   \renewcommand{\DOTI}[1]{%
%    \mghrulefill{\RW}\par\nobreak
    \CTV\FmTi{#1}\par\nobreak
    \vskip 75\p@
    \hbox to 105mm{\hskip -5mm\leavevmode\leaders\hrule height 1pt \hfill}%
    \vskip 5\p@
    }

  \renewcommand{\DOTIS}[1]{%
    \CTV\FmTi{#1}\par\nobreak
%    \vskip 60\p@
    } 

\def\@makechapterhead#1{%
  \vspace*{0\p@}%
  {\parindent \z@ \raggedright \normalfont
    \ifnum \c@secnumdepth >\m@ne
      \DOCH
    \fi
    \interlinepenalty\@M
    \DOTI{#1}
    \par
    \vskip 5\p@
  }}

\def\@schapter#1{\if@twocolumn
                   \@topnewpage[\@makeschapterhead{#1}]%
                 \else
                   \@makeschapterhead{#1}%
                   \@afterheading
                 \fi}

\def\@makeschapterhead#1{%
  \vspace*{0\p@}%
  {\parindent \z@ \raggedright
    \normalfont
    \interlinepenalty\@M
    \DOTIS{#1}
    \vskip 40\p@
   }} 

%%%
%%% SECTION
%%%  inspired of smcho's smchopretty.sty
%%%
\renewcommand \thesection {\@arabic\c@section}
\def\sectionfont{\normalfont\fontsize{11.5}{11.5}\selectfont\bfseries\sffamily}% 
\definecolor{GrayEighth}{gray}{.8}
\def\GrayEighth{\color{GrayEighth}}
\renewcommand\section{\@startsection {section}{1}{-64pt}%
                      {-12pt \@plus -2pt \@minus -.5pt}%
                      {5pt \@plus 1\p@ \@minus .4\p@}%
                      {\sectionfont}}
\def\@seccntformat#1{\csname the#1\endcsname}
%
\def\@sect#1#2#3#4#5#6[#7]#8{\ifnum #2>\c@secnumdepth
     \let\@svsec\@empty\else
     \refstepcounter{#1}%
     \let\@@protect\protect
     \def\protect{\noexpand\protect\noexpand}%
     \edef\@svsec{\@seccntformat{#1}}%
     \let\protect\@@protect\fi
     \@tempskipa #5\relax
      	\ifdim \@tempskipa>\z@
        	\begingroup #6\relax
          		\noindent\hskip #3\@hangfrom{\hbox to 17mm{\hfill{\GrayEighth%
          		\ifnum #2 = 1 \vrule height12pt depth4pt width17mm%
          		\else%\ifnum #2 > 1
         		\vrule height0pt depth0pt width17mm\fi
          		}\llap{\@svsec\hskip2pt}}\hspace*{6mm}}%
                      {\interlinepenalty \@M \hangindent0pt#8\par}%
        	\endgroup
       \csname #1mark\endcsname{#7}\addcontentsline
         	{toc}{#1}{\ifnum #2>\c@secnumdepth \else
                      \protect\numberline{\csname the#1\endcsname}\fi
                  #7}\else
        \def\@svsechd{#6\hskip #3\relax  %% \relax added 2 May 90
                  \@svsec #8\csname #1mark\endcsname
                  {#7}\addcontentsline
                      {toc}{#1}{\ifnum #2>\c@secnumdepth \else
                      \protect\numberline{\csname the#1\endcsname}%
                         \fi
                   #7}}\fi
     \@xsect{#5}%
}
%%
%% provides user section command.
%%
\newcommand\msmpsection[1]{%
	\section{#1}%
}

%%%
%%% TITLE PAGE:
%%%  code from http://zoonek.free.kr/LaTeX/LaTeX_samples_title/0.html
%%%
\def\thickhrulefill{\leavevmode \leaders \hrule height 1pt\hfill \kern \z@}
\def\title@h@font{\hfontfamily{cs}}
\definecolor{TitlePageBackgroundColor}{rgb}{.81,0.78,0.9}

\newcommand\msmpmaketitle{%
	\ClearShipoutPicture
	\maketitle
}

\renewcommand{\maketitle}{\begin{titlepage}%
	\pagestyle{empty}%
	\pagecolor{TitlePageBackgroundColor}%
    \let\footnotesize\small
    \let\footnoterule\relax
    \parindent \z@
    \reset@font
    \null
    \vskip 10\p@
    \hbox{\mbox{%
        \hspace{4pt}%
        \fbox{\includegraphics[width=3em]{dessin}}%
        \hspace{4pt}
        }%
      \vrule depth 0.9\textheight%
      \mbox{\hspace{2em}}
      \vtop{% %%%%%%%%%%%%%%%%%%
        \vskip 40\p@
        \begin{flushleft}
          \Large\sffamily \@author \par
        \end{flushleft}
        \vskip 80\p@
        \begin{flushleft}
          \huge \title@h@font\bfseries \@title \par
        \end{flushleft}
        \vfil
        }}
    \null
  \end{titlepage}%
  \setcounter{footnote}{0}%
  \pagecolor{white}%
}

%%
%% QUOTE, QUOTATION
%%
\renewenvironment{quotation}
               {\list{}{\leftmargin 1em%
               			\listparindent 1em%
                        \itemindent    \listparindent
                        \rightmargin   1em %\leftmargin
                        \parsep        \z@ \@plus\p@}%
                \small\item\relax}
               {\endlist\normalfont}
\renewenvironment{quote}
               {\list{}{\leftmargin 1.5em%
               	\rightmargin 1em}
                \small\item\relax}%
               {\endlist\normalfont}

\newenvironment{fullquote}
			   {\list{}{\leftmargin 0em%
			   			\rightmargin\leftmargin
			   			\listparindent 1em%
			   			\itemindent\listparindent
			   			\parsep \z@}%
			   	\small\item\relax}
			   {\endlist\normalfont}

%% And other settings
%%
\providecommand\makethinhangul{}
\providecommand\pagewiselinenumbers{%
	\typeout{line number disabled.}\relax
}

\RequirePackage[bottom]{footmisc}
\renewcommand\thefootnote{}
\raggedbottom

\endinput
%% end of 'mysimple.cls'